@@ -35,8 +35,11 @@ static const QMap<UpdatesStatus, ControlPanelType> ControlPanelTypeMapping = {
 UpdateModel::UpdateModel(QObject* parent)
     : QObject(parent)
     , m_lastoreDaemonStatus(0)
+    , m_updateProhibited(false)
+    , m_systemActivation(false)
     , m_isUpdateDisabled(false)
-    , m_systemActivation(true)
+    , m_updateDisabledIcon("")
+    , m_updateDisabledTips("")
     , m_batterIsOK(false)
     , m_lastStatus(Default)
     , m_showCheckUpdate(false)
@@ -57,6 +60,7 @@ UpdateModel::UpdateModel(QObject* parent)
     , m_backingUpListModel(new UpdateListModel(this))
     , m_backupFailedListModel(new UpdateListModel(this))
     , m_downloadWaiting(false)
+    , m_downloadPaused(false)
     , m_upgradeWaiting(false)
     , m_downloadProgress(0.0)
     , m_distUpgradeProgress(0.0)
@@ -65,6 +69,7 @@ UpdateModel::UpdateModel(QObject* parent)
     , m_downloadFailedTips("")
     , m_installFailedTips("")
     , m_backupFailedTips("")
+    , m_installLog("")
     , m_isUpdatable(false)
     , m_securityUpdateEnabled(false)
     , m_thirdPartyUpdateEnabled(false)
@@ -99,9 +104,57 @@ void UpdateModel::setLastoreDaemonStatus(int status)
     m_lastoreDaemonStatus = status;
 
     if (LastoreDaemonDConfigStatusHelper::isUpdateDisabled(m_lastoreDaemonStatus)) {
+        setUpdateProhibited(true);
+    } else {
+        setUpdateProhibited(false);
+    }
+}
+
+void UpdateModel::setUpdateProhibited(bool prohibited)
+{
+    if (m_updateProhibited == prohibited) {
+        return;
+    }
+    m_updateProhibited = prohibited;
+    Q_EMIT updateProhibitedChanged(prohibited);
+
+    refreshIsUpdateDisabled();
+}
+
+void UpdateModel::setSystemActivation(bool systemActivation)
+{
+    qCInfo(DCC_UPDATE_MODEL) << "System activation:" << systemActivation;
+    if (m_systemActivation == systemActivation) {
+        return;
+    }
+    m_systemActivation = systemActivation;
+    Q_EMIT systemActivationChanged(systemActivation);
+
+    refreshIsUpdateDisabled();
+}
+
+void UpdateModel::refreshIsUpdateDisabled()
+{
+    if (!m_systemActivation) {
         setIsUpdateDisabled(true);
+        setUpdateDisabledIcon("update_no_active");
+        setUpdateDisabledTips(tr("Your system is not activated, and it failed to connect to update services"));
+    } else if (m_immutableAutoRecovery) {
+        setIsUpdateDisabled(true);
+        setUpdateDisabledIcon("update_prohibit");
+        setUpdateDisabledTips(tr("The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator"));
+    } else if (m_updateProhibited) {
+        setIsUpdateDisabled(true);
+        setUpdateDisabledIcon("update_prohibit");
+        setUpdateDisabledTips(tr("The system updates are disabled. Please contact your administrator for help"));
+    } else if (updateModeDisabled()) {
+        setIsUpdateDisabled(true);
+        setUpdateDisabledIcon("update_nice_service");
+        setUpdateDisabledTips(tr("Turn on the switches under Update Content to get better experiences"));
     } else {
         setIsUpdateDisabled(false);
+        setUpdateDisabledIcon("");
+        setUpdateDisabledTips("");
     }
 }
 
@@ -114,14 +167,22 @@ void UpdateModel::setIsUpdateDisabled(bool disabled)
     Q_EMIT isUpdateDisabledChanged(disabled);
 }
 
-void UpdateModel::setSystemActivation(bool systemActivation)
+void UpdateModel::setUpdateDisabledIcon(const QString &icon)
 {
-    qCInfo(DCC_UPDATE_MODEL) << "System activation:" << systemActivation;
-    if (m_systemActivation == systemActivation) {
+    if (m_updateDisabledIcon == icon)
         return;
-    }
-    m_systemActivation = systemActivation;
-    Q_EMIT systemActivationChanged(systemActivation);
+
+    m_updateDisabledIcon = icon;
+    Q_EMIT updateDisabledIconChanged();
+}
+
+void UpdateModel::setUpdateDisabledTips(const QString &tips)
+{
+    if (m_updateDisabledTips == tips)
+        return;
+
+    m_updateDisabledTips = tips;
+    Q_EMIT updateDisabledTipsChanged();
 }
 
 void UpdateModel::setBatterIsOK(bool ok)
@@ -147,6 +208,17 @@ void UpdateModel::setLastStatus(const UpdatesStatus& status, int line, int types
     }
 }
 
+void UpdateModel::setImmutableAutoRecovery(bool value)
+{
+    qCInfo(DCC_UPDATE_MODEL) << "Set immutable auto recovery: " << value;
+    if (m_immutableAutoRecovery == value)
+        return;
+
+    m_immutableAutoRecovery = value;
+    Q_EMIT immutableAutoRecoveryChanged(value);
+    refreshIsUpdateDisabled();
+}
+
 void UpdateModel::setShowCheckUpdate(bool value)
 {
     if (m_showCheckUpdate == value)
@@ -201,11 +273,6 @@ void UpdateModel::updateCheckUpdateUi()
             setCheckUpdateErrTips(tr("Your system is up to date"));
             setCheckUpdateIcon("update_abreast_of_time");
             break;
-        case AllUpdateModeDisabled:
-            setCheckUpdateErrTips(tr("Turn on the switches under Update Content to get better experiences"));
-            setCheckUpdateIcon("update_nice_service");
-            setCheckBtnText("");
-            break;
         default:
             setCheckBtnText(tr(""));
             return;
@@ -237,7 +304,7 @@ void UpdateModel::setLastCheckUpdateTime(const QString& lastTime)
     emit lastCheckUpdateTimeChanged();
 }
 
-void UpdateModel::setCheckUpdateMode(int value)
+void UpdateModel::setCheckUpdateMode(quint64 value)
 {
     qCInfo(DCC_UPDATE_MODEL) << "Set check update mode: " << value;
     if (m_checkUpdateMode == value)
@@ -247,9 +314,17 @@ void UpdateModel::setCheckUpdateMode(int value)
     Q_EMIT checkUpdateModeChanged(value);
 
     // 升级时切换用户，再切回来的时候收到的信号时乱序，可能会先收到updateStatusChanged再收到checkUpdateModeChanged
+    refreshUpdateItemsChecked();
     refreshUpdateStatus();
 }
 
+void UpdateModel::refreshUpdateItemsChecked()
+{
+    for (const auto item : m_allUpdateInfos.values()) {
+        item->setIsChecked(m_checkUpdateMode & item->updateType());
+    }
+}
+
 void UpdateModel::setPreUpdatelistModel(UpdateListModel *newPreUpdatelistModel)
 {
     if (m_preUpdatelistModel == newPreUpdatelistModel)
@@ -340,6 +415,15 @@ void UpdateModel::setDownloadWaiting(bool waiting)
     Q_EMIT downloadWaitingChanged(waiting);
 }
 
+void UpdateModel::setDownloadPaused(bool paused)
+{
+    if (m_downloadPaused == paused)
+        return;
+
+    m_downloadPaused = paused;
+    Q_EMIT downloadPausedChanged(paused);
+}
+
 void UpdateModel::setUpgradeWaiting(bool waiting)
 {
     if (m_upgradeWaiting == waiting)
@@ -412,6 +496,18 @@ void UpdateModel::setBackupFailedTips(const QString &newBackupFailedTips)
     emit backupFailedTipsChanged();
 }
 
+void UpdateModel::setUpdateLog(const QString &log)
+{
+    m_installLog = log;
+    emit updateInstallLogChanged(m_installLog);
+}
+
+void UpdateModel::appendUpdateLog(const QString &log)
+{
+    m_installLog += log;
+    emit updateInstallLogChanged(m_installLog);
+}
+
 void UpdateModel::addUpdateInfo(UpdateItemInfo* info)
 {
     if (info == nullptr)
@@ -863,6 +959,7 @@ void UpdateModel::setUpdateMode(quint64 updateMode)
 
     m_updateMode = updateMode;
 
+    refreshIsUpdateDisabled();
     setUpdateItemEnabled();
     refreshUpdateStatus();
     updateAvailableState();
@@ -917,16 +1014,14 @@ bool UpdateModel::idleDownloadEnabled() const
     return m_idleDownloadConfig.idleDownloadEnabled;
 }
 
-int UpdateModel::beginTime() const
+QString UpdateModel::beginTime() const
 {
-    QTime time = QTime::fromString(m_idleDownloadConfig.beginTime);
-    return time.hour() * 60 + time.minute();
+    return m_idleDownloadConfig.beginTime;
 }
 
-int UpdateModel::endTime() const
+QString UpdateModel::endTime() const
 {
-    QTime time = QTime::fromString(m_idleDownloadConfig.endTime);
-    return time.hour() * 60 + time.minute();
+    return m_idleDownloadConfig.endTime;
 }
 
 void UpdateModel::setIdleDownloadConfig(const IdleDownloadConfig& config)
@@ -1107,9 +1202,9 @@ void UpdateModel::onUpdatePropertiesChanged(const QString& interfaceName, const
         if (changedProperties.contains("CheckUpdateMode")) {
             // 用户A、B都打开控制中心，用户A多次修改CheckUpdateMode后切换到用户B，控制中心会立刻收到多个改变信号
             // 增加一个100ms的防抖，只取最后一次的数值
-            static int tmpValue = 0;
+            static quint64 tmpValue = 0;
             static QTimer* timer = nullptr;
-            tmpValue = changedProperties.value("CheckUpdateMode").toInt();
+            tmpValue = changedProperties.value("CheckUpdateMode").toULongLong();
             if (!timer) {
                 timer = new QTimer(this);
                 timer->setInterval(100);
