@@ -21,8 +21,11 @@ class UpdateModel : public QObject
 {
     Q_OBJECT
 
+    Q_PROPERTY(bool updateProhibited READ updateProhibited NOTIFY updateProhibitedChanged FINAL)
+    Q_PROPERTY(bool systemActivation READ systemActivation NOTIFY systemActivationChanged FINAL)
     Q_PROPERTY(bool isUpdateDisabled READ isUpdateDisabled NOTIFY isUpdateDisabledChanged FINAL)
-    Q_PROPERTY(bool systemActivation READ systemActivation WRITE setSystemActivation NOTIFY systemActivationChanged FINAL)
+    Q_PROPERTY(QString updateDisabledIcon READ updateDisabledIcon NOTIFY updateDisabledIconChanged FINAL)
+    Q_PROPERTY(QString updateDisabledTips READ updateDisabledTips NOTIFY updateDisabledTipsChanged FINAL)
     Q_PROPERTY(bool batterIsOK READ batterIsOK NOTIFY batterIsOKChanged FINAL)
     Q_PROPERTY(int lastStatus READ lastStatus  NOTIFY lastStatusChanged FINAL)
 
@@ -47,6 +50,7 @@ class UpdateModel : public QObject
     Q_PROPERTY(UpdateListModel *backupFailedListModel READ backupFailedListModel NOTIFY backupFailedListModelChanged FINAL)    
 
     Q_PROPERTY(bool downloadWaiting READ downloadWaiting NOTIFY downloadWaitingChanged FINAL)
+    Q_PROPERTY(bool downloadPaused READ downloadPaused NOTIFY downloadPausedChanged FINAL)
     Q_PROPERTY(bool upgradeWaiting READ upgradeWaiting NOTIFY upgradeWaitingChanged FINAL)
 
     Q_PROPERTY(double downloadProgress READ downloadProgress NOTIFY downloadProgressChanged FINAL)
@@ -57,6 +61,7 @@ class UpdateModel : public QObject
     Q_PROPERTY(QString downloadFailedTips READ downloadFailedTips NOTIFY downloadFailedTipsChanged FINAL)
     Q_PROPERTY(QString installFailedTips READ installFailedTips NOTIFY installFailedTipsChanged FINAL)
     Q_PROPERTY(QString backUpFailedTips READ backupFailedTips NOTIFY backupFailedTipsChanged FINAL)
+    Q_PROPERTY(QString updateInstallLog READ updateInstallLog NOTIFY updateInstallLogChanged FINAL)
 
     // ---------------更新设置页面数据---------------
     Q_PROPERTY(bool securityUpdateEnabled READ securityUpdateEnabled WRITE setSecurityUpdateEnabled NOTIFY securityUpdateEnabledChanged FINAL)
@@ -69,8 +74,8 @@ class UpdateModel : public QObject
     Q_PROPERTY(QString downloadSpeedLimitSize READ downloadSpeedLimitSize NOTIFY downloadSpeedLimitConfigChanged FINAL)
     Q_PROPERTY(bool autoDownloadUpdates READ autoDownloadUpdates WRITE setAutoDownloadUpdates NOTIFY autoDownloadUpdatesChanged FINAL)
     Q_PROPERTY(bool idleDownloadEnabled READ idleDownloadEnabled NOTIFY idleDownloadConfigChanged FINAL)
-    Q_PROPERTY(int beginTime READ beginTime NOTIFY idleDownloadConfigChanged FINAL)
-    Q_PROPERTY(int endTime READ endTime NOTIFY idleDownloadConfigChanged FINAL)
+    Q_PROPERTY(QString beginTime READ beginTime NOTIFY idleDownloadConfigChanged FINAL)
+    Q_PROPERTY(QString endTime READ endTime NOTIFY idleDownloadConfigChanged FINAL)
     Q_PROPERTY(bool updateNotify READ updateNotify WRITE setUpdateNotify NOTIFY updateNotifyChanged FINAL)
     Q_PROPERTY(bool autoCleanCache READ autoCleanCache WRITE setAutoCleanCache NOTIFY autoCleanCacheChanged FINAL)
     Q_PROPERTY(bool smartMirrorSwitch READ smartMirrorSwitch WRITE setSmartMirrorSwitch NOTIFY smartMirrorSwitchChanged FINAL)
@@ -87,11 +92,22 @@ public:
     int lastoreDaemonStatus() const { return m_lastoreDaemonStatus; }
     void setLastoreDaemonStatus(int status);
 
-    bool isUpdateDisabled() const { return m_isUpdateDisabled; }
-    void setIsUpdateDisabled(bool disabled);
+    bool updateProhibited() const { return m_updateProhibited; }
+    void setUpdateProhibited(bool prohibited);
 
     bool systemActivation() const { return m_systemActivation; }
     void setSystemActivation(bool systemActivation);
+    
+    void refreshIsUpdateDisabled();
+
+    bool isUpdateDisabled() const { return m_isUpdateDisabled; }
+    void setIsUpdateDisabled(bool disabled);
+
+    QString updateDisabledIcon() const { return m_updateDisabledIcon; }
+    void setUpdateDisabledIcon(const QString &icon);
+
+    QString updateDisabledTips() const { return m_updateDisabledTips; }
+    void setUpdateDisabledTips(const QString &tips);
 
     bool batterIsOK() const { return m_batterIsOK; }
     void setBatterIsOK(bool ok);
@@ -99,6 +115,9 @@ public:
     int lastStatus() const { return m_lastStatus; }
     void setLastStatus(const UpdatesStatus &status, int line, int types = 0);
 
+    bool immutableAutoRecovery() const { return m_immutableAutoRecovery; }
+    void setImmutableAutoRecovery(bool value);
+
     // ---------------检查更新页面数据---------------
     bool showCheckUpdate() const { return m_showCheckUpdate; }
     void setShowCheckUpdate(bool value);
@@ -122,9 +141,9 @@ public:
     QString lastCheckUpdateTime() const { return m_lastCheckUpdateTime; }
     void setLastCheckUpdateTime(const QString &lastTime);
 
-    int checkUpdateMode() const { return m_checkUpdateMode; }
-    void setCheckUpdateMode(int value);
-
+    quint64 checkUpdateMode() const { return m_checkUpdateMode; }
+    void setCheckUpdateMode(quint64 value);
+    void refreshUpdateItemsChecked();
 
     // ---------------下载、备份、安装列表数据---------------
     UpdateListModel *preUpdatelistModel() const { return m_preUpdatelistModel; }
@@ -157,6 +176,9 @@ public:
     bool downloadWaiting() const { return m_downloadWaiting; }
     void setDownloadWaiting(bool waiting);
 
+    bool downloadPaused() const { return m_downloadPaused; }
+    void setDownloadPaused(bool paused);
+
     bool upgradeWaiting() const { return m_upgradeWaiting; }
     void setUpgradeWaiting(bool waiting);
 
@@ -181,6 +203,10 @@ public:
     QString backupFailedTips() const { return m_backupFailedTips; }
     void setBackupFailedTips(const QString &newBackupFailedTips);
 
+    QString updateInstallLog() const { return m_installLog; }
+    void setUpdateLog(const QString &log);
+    void appendUpdateLog(const QString &log);
+
     QMap<UpdateType, UpdateItemInfo *> getAllUpdateInfos() const { return m_allUpdateInfos; }
     UpdateItemInfo *updateItemInfo(UpdateType type) const { return m_allUpdateInfos.value(type); }
     void addUpdateInfo(UpdateItemInfo *info);
@@ -239,8 +265,8 @@ public:
     void setAutoDownloadUpdates(bool autoDownloadUpdates);
 
     bool idleDownloadEnabled() const;
-    int beginTime() const;
-    int endTime() const;
+    QString beginTime() const;
+    QString endTime() const;
     IdleDownloadConfig idleDownloadConfig() const { return m_idleDownloadConfig; }
     void setIdleDownloadConfig(const IdleDownloadConfig &config);
 
@@ -295,11 +321,15 @@ public slots:
                                    const QStringList &invalidatedProperties);
 
 Q_SIGNALS:
-    void isUpdateDisabledChanged(bool isDisabled);
+    void updateProhibitedChanged(bool prohibited);
     void systemActivationChanged(bool systemActivation);
+    void isUpdateDisabledChanged(bool isDisabled);
+    void updateDisabledIconChanged();
+    void updateDisabledTipsChanged();
 
     void batterIsOKChanged(bool isOK);
     void lastStatusChanged(int status);
+    void immutableAutoRecoveryChanged(bool value);
 
     // 检查更新页面数据
     void showCheckUpdateChanged();
@@ -309,7 +339,7 @@ Q_SIGNALS:
     void checkUpdateErrTipsChanged();
     void checkBtnTextChanged();
     void lastCheckUpdateTimeChanged();
-    void checkUpdateModeChanged(int);
+    void checkUpdateModeChanged(quint64);
 
     // 下载、备份、安装列表数据
     void preUpdatelistModelChanged();
@@ -323,6 +353,7 @@ Q_SIGNALS:
     void backupFailedListModelChanged();
 
     void downloadWaitingChanged(bool waiting);
+    void downloadPausedChanged(bool paused);
     void upgradeWaitingChanged(bool waiting);
 
     void downloadProgressChanged(const double &progress);
@@ -333,6 +364,7 @@ Q_SIGNALS:
     void downloadFailedTipsChanged();
     void installFailedTipsChanged();
     void backupFailedTipsChanged();
+    void updateInstallLogChanged(const QString &log);
 
     void updateInfoChanged(UpdateType);
     void isUpdatableChanged(const bool isUpdatablePackages);
@@ -363,10 +395,14 @@ Q_SIGNALS:
 
 private:
     int m_lastoreDaemonStatus; // 比较重要的数值，每个位标识不同的含义，使用 LastoreDaemonDConfigStatusHelper 对它进行解析
-    bool m_isUpdateDisabled;
+    bool m_updateProhibited;
     bool m_systemActivation;
+    bool m_isUpdateDisabled;
+    QString m_updateDisabledIcon;
+    QString m_updateDisabledTips;
     bool m_batterIsOK;
     int m_lastStatus;
+    bool m_immutableAutoRecovery;
 
     // 检查更新页面数据
     bool m_showCheckUpdate;
@@ -376,7 +412,7 @@ private:
     QString m_checkUpdateErrTips;
     QString m_checkBtnText;
     QString m_lastCheckUpdateTime;
-    int m_checkUpdateMode;
+    quint64 m_checkUpdateMode;
 
     // 下载、备份、安装列表数据
     UpdateListModel *m_preUpdatelistModel; // preUpdateList qml data
@@ -389,6 +425,7 @@ private:
     UpdateListModel *m_backingUpListModel; // backing up qml data
     UpdateListModel *m_backupFailedListModel; // backup failed qml data
     bool m_downloadWaiting;
+    bool m_downloadPaused;
     bool m_upgradeWaiting;
     double m_downloadProgress;
     double m_distUpgradeProgress;
@@ -397,6 +434,7 @@ private:
     QString m_downloadFailedTips;
     QString m_installFailedTips;
     QString m_backupFailedTips;
+    QString m_installLog;
 
     QMap<UpdateType, UpdateItemInfo *> m_allUpdateInfos;
     QMap<UpdatesStatus, UpdateErrorType> m_errorMap;
