@@ -40,7 +40,7 @@ static const QStringList DCC_CONFIG_FILES {
     "/usr/share/dde-control-center/dde-control-center.conf"
 };
 
-void notifyError(const QString &summary, const QString &body)
+void notifyInfo(const QString &summary, const QString &body)
 {
     DUtil::DNotifySender(summary)
             .appIcon("")
@@ -50,7 +50,7 @@ void notifyError(const QString &summary, const QString &body)
             .call();
 }
 
-void notifyErrorWithoutBody(const QString &summary)
+void notifyInfoWithoutBody(const QString &summary)
 {
     DUtil::DNotifySender(summary)
             .appIcon("")
@@ -105,6 +105,7 @@ UpdateWorker::UpdateWorker(UpdateModel* model, QObject* parent)
     , m_model(model)
     , m_updateInter(new UpdateDBusProxy(this))
     , m_lastoreHeartBeatTimer(new QTimer(this))
+    , m_logWatcherHelper(new LogWatcherHelper(this))
     , m_machineid(std::nullopt)
     , m_testingChannelUrl(std::nullopt)
     , m_doCheckUpdates(false)
@@ -157,6 +158,7 @@ void UpdateWorker::initConnect()
     connect(m_updateInter, &UpdateDBusProxy::JobListChanged, this, &UpdateWorker::onJobListChanged);
     connect(m_updateInter, &UpdateDBusProxy::UpdateStatusChanged, this, &UpdateWorker::onUpdateStatusChanged);
     connect(m_updateInter, &UpdateDBusProxy::ClassifiedUpdatablePackagesChanged, this, &UpdateWorker::onClassifiedUpdatablePackagesChanged);
+    connect(m_updateInter, &UpdateDBusProxy::ImmutableAutoRecoveryChanged, m_model, &UpdateModel::setImmutableAutoRecovery);
 
     QDBusConnection::systemBus().connect("org.deepin.dde.Lastore1",
                                          "/org/deepin/dde/Lastore1",
@@ -174,6 +176,8 @@ void UpdateWorker::initConnect()
     m_lastoreHeartBeatTimer->start();
     connect(m_lastoreHeartBeatTimer, &QTimer::timeout, this, &UpdateWorker::refreshLastTimeAndCheckCircle);
 
+    connect(m_logWatcherHelper, &LogWatcherHelper::incrementalDataChanged, m_model, &UpdateModel::appendUpdateLog);
+
     connect(DConfigWatcher::instance(), &DConfigWatcher::notifyDConfigChanged, [this](const QString &moduleName, const QString &configName) {
         qCDebug(DCC_UPDATE_WORKER) << "Config changed:" << moduleName << configName;
 
@@ -215,6 +219,7 @@ void UpdateWorker::activate()
     m_model->setUpdateNotify(m_updateInter->updateNotify());
     m_model->setAutoCleanCache(m_updateInter->autoClean());
     m_model->setP2PUpdateEnabled(m_updateInter->p2pUpdateEnable());
+    m_model->setImmutableAutoRecovery(m_updateInter->immutableAutoRecovery());
     if (IsCommunitySystem) {
         m_model->setSmartMirrorSwitch(m_updateInter->enable());
     }
@@ -224,31 +229,37 @@ void UpdateWorker::activate()
 
     m_model->setUpdateStatus(m_updateInter->updateStatus().toUtf8());
 
-    if (!m_model->isUpdateDisabled()) {
-        // 获取当前的job
-        const QList<QDBusObjectPath> jobs = m_updateInter->jobList();
-        if (jobs.count() > 0) {
-            onJobListChanged(jobs);
-            // 如果处于下载中或者安装中的时候直接显示更新内容，不检查更新
-            const bool isDownloading = m_downloadJob && m_downloadJob->status() != "failed";
-            const bool isUpgrading = m_distUpgradeJob && m_distUpgradeJob->status() != "failed";
-            if (isUpgrading || isDownloading) {
-                auto watcher = new QDBusPendingCallWatcher(m_updateInter->GetUpdateLogs(SystemUpdate | SecurityUpdate), this);
-                connect(watcher, &QDBusPendingCallWatcher::finished, [this, watcher] {
-                    watcher->deleteLater();
-                    if (!watcher->isError()) {
-                        QDBusPendingReply<QString> reply = watcher->reply();
-                        UpdateLogHelper::ref().handleUpdateLog(reply.value());
-                    } else {
-                        qCWarning(DCC_UPDATE_WORKER) << "Get update log failed";
+    // 获取当前的job
+    const QList<QDBusObjectPath> jobs = m_updateInter->jobList();
+    if (jobs.count() > 0) {
+        onJobListChanged(jobs);
+        // 如果处于下载中或者安装中的时候直接显示更新内容，不检查更新
+        const bool isDownloading = m_downloadJob && m_downloadJob->status() != "failed";
+        const bool isUpgrading = m_distUpgradeJob && m_distUpgradeJob->status() != "failed";
+        if (isUpgrading || isDownloading) {
+            auto watcher = new QDBusPendingCallWatcher(m_updateInter->GetUpdateLogs(SystemUpdate | SecurityUpdate), this);
+            connect(watcher, &QDBusPendingCallWatcher::finished, [this, watcher] {
+                if (!watcher->isError()) {
+                    QDBusPendingReply<QString> reply = watcher->reply();
+                    UpdateLogHelper::ref().handleUpdateLog(reply.value());
+                    auto resultMap = m_model->getAllUpdateInfos();
+                    for (UpdateType type : resultMap.keys()) {
+                        UpdateLogHelper::ref().updateItemInfo(resultMap.value(type));
                     }
-                    // 日志处理完了再显示更新内容界面
-                    m_model->setLastStatus(CheckingSucceed, __LINE__);
-                    setUpdateInfo();
-                });
-            }
+                } else {
+                    qCWarning(DCC_UPDATE_WORKER) << "Get update log failed";
+                }
+                // 日志处理完了再显示更新内容界面
+                m_model->setLastStatus(CheckingSucceed, __LINE__);
+                setUpdateInfo();
+                watcher->deleteLater();
+            });
         }
     }
+    
+    QTimer::singleShot(0, this, [this]() {
+        m_logWatcherHelper->startWatchFile();
+    });
 }
 
 void UpdateWorker::initConfig()
@@ -370,14 +381,7 @@ void UpdateWorker::checkNeedDoUpdates()
 {
     qCInfo(DCC_UPDATE_WORKER) << "check need do updates";
 
-    if (m_model->updateModeDisabled()) {
-        m_model->setShowCheckUpdate(true);
-        m_model->setCheckUpdateStatus(UpdatesStatus::AllUpdateModeDisabled);
-        return;
-    }
-
-    if (m_model->isUpdateDisabled() || !m_model->systemActivation()) {
-        qCDebug(DCC_UPDATE_WORKER) << "update disabled:" << m_model->isUpdateDisabled() << " system activation:" << m_model->systemActivation();
+    if (m_model->isUpdateDisabled()) {
         m_model->setShowCheckUpdate(false);
         return;
     }
@@ -507,6 +511,7 @@ void UpdateWorker::setUpdateInfo()
             isUpdated = false;
         }
     }
+    m_model->refreshUpdateItemsChecked();
     m_model->refreshUpdateStatus();
     m_model->updateAvailableState();
     m_model->setLastStatus(isUpdated ? Updated : UpdatesAvailable, __LINE__);
@@ -619,14 +624,14 @@ void UpdateWorker::stopDownload()
     cleanLaStoreJob(m_downloadJob);
 }
 
-void UpdateWorker::onDownloadJobCtrl(int updateCtrlType)
+void UpdateWorker::downloadJobCtrl(UpdateCtrlType type)
 {
     if (m_downloadJob == nullptr) {
         qCWarning(DCC_UPDATE_WORKER) << "Download job is nullptr";
         return;
     }
 
-    switch (updateCtrlType) {
+    switch (type) {
     case UpdateCtrlType::Start:
         qCInfo(DCC_UPDATE_WORKER) << "Start download job";
         m_updateInter->StartJob(m_downloadJob->id());
@@ -689,12 +694,18 @@ void UpdateWorker::doUpgrade(int updateTypes, bool doBackup)
 
 void UpdateWorker::reStart()
 {
-    DDBusSender()
-    .service("com.deepin.dde.shutdownFront")
-    .interface("com.deepin.dde.shutdownFront")
-    .path("/com/deepin/dde/shutdownFront")
-    .method("Restart")
-    .call();
+    qCInfo(DCC_UPDATE_WORKER) << "request restart";
+    m_updateInter->Restart();
+}
+
+void UpdateWorker::modalUpgrade(bool rebootAfterUpgrade)
+{
+    qCInfo(DCC_UPDATE_WORKER) << "request modal upgrade, reboot after upgrade:" << rebootAfterUpgrade;
+    if (rebootAfterUpgrade) {
+        m_updateInter->UpdateAndReboot();
+    } else {
+        m_updateInter->UpdateAndShutdown();
+    }
 }
 
 void UpdateWorker::setBackupJob(const QString& jobPath)
@@ -790,11 +801,14 @@ void UpdateWorker::setDownloadSpeedLimitEnabled(bool enable)
 {
     auto config = m_model->speedLimitConfig();
     config.downloadSpeedLimitEnabled = enable;
+    // dbus返回需要1s，导致界面更新慢，这里直接先更新model
+    m_model->setSpeedLimitConfig(config.toJson().toUtf8());
     setDownloadSpeedLimitConfig(config.toJson());
 }
 
 void UpdateWorker::setDownloadSpeedLimitSize(const QString& size)
 {
+    qCDebug(DCC_UPDATE_WORKER) << "set download speed limit size" << size;
     auto config = m_model->speedLimitConfig();
     config.limitSpeed = size;
     setDownloadSpeedLimitConfig(config.toJson());
@@ -827,24 +841,26 @@ void UpdateWorker::setIdleDownloadEnabled(bool enable)
     setIdleDownloadConfig(config);
 }
 
-void UpdateWorker::setIdleDownloadBeginTime(int time)
+void UpdateWorker::setIdleDownloadBeginTime(QString time)
 {
     auto config = m_model->idleDownloadConfig();
-    config.beginTime = timeToString(time);
+    config.beginTime = time;
     config.endTime = adjustTimeFunc(config.beginTime, config.endTime, true);
     setIdleDownloadConfig(config);
 }
 
-void UpdateWorker::setIdleDownloadEndTime(int time)
+void UpdateWorker::setIdleDownloadEndTime(QString time)
 {
     auto config = m_model->idleDownloadConfig();
-    config.endTime = timeToString(time);
+    config.endTime = time;
     config.beginTime = adjustTimeFunc(config.beginTime, config.endTime, false);
     setIdleDownloadConfig(config);
 }
 
 void UpdateWorker::setIdleDownloadConfig(const IdleDownloadConfig& config)
 {
+    // 避免dbus延时返回，导致界面更新慢，这里直接先更新model
+    m_model->setIdleDownloadConfig(config);
     QDBusPendingCall call = m_updateInter->SetIdleDownloadConfig(QString(config.toJson()));
     QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(call, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [call, watcher] {
@@ -855,15 +871,6 @@ void UpdateWorker::setIdleDownloadConfig(const IdleDownloadConfig& config)
     });
 }
 
-QString UpdateWorker::timeToString(int value)
-{
-    int time = value / 60;
-    QString timeStr = time < 10 ? ("0" + QString::number(time)) : QString::number(time);
-    int minute = value % 60;
-    QString minuteStr = minute < 10 ? ("0" + QString::number(minute)) : QString::number(minute);
-    return timeStr + ":" + minuteStr;
-}
-
 // 规则：开始时间和结束时间不能相等，否则默认按相隔五分钟处理
 // 修改开始时间时，如果不满足规则，那么自动调整结束时间，结束时间=开始时间+5分钟
 // 修改结束时间时，如果不满足规则，那么自动调整开始时间，开始时间=结束时间-5分钟
@@ -1269,12 +1276,40 @@ void UpdateWorker::onRequestRetry(int type, int updateTypes)
 
 void UpdateWorker::setCheckUpdateMode(int type, bool isChecked)
 {
-    const int currentMode = m_model->checkUpdateMode();
-    const int outMode = isChecked ? (currentMode | type) : (currentMode & ~type);
+    quint64 currentMode = m_model->checkUpdateMode();
+    quint64 outMode = isChecked ? (currentMode | type) : (currentMode & ~type);
 
     m_updateInter->setCheckUpdateMode(outMode);
 }
 
+void UpdateWorker::exportLogToDesktop()
+{
+    // 获取桌面路径
+    QString desktopPath = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+    if (desktopPath.isEmpty()) {
+        // 如果无法获取桌面路径，使用主目录
+        desktopPath = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+    }
+
+    // 生成文件名：更新日志_yyyy_mm_dd_HH.MM.SS.txt
+    QString timestamp = QDateTime::currentDateTime().toString("yyyy_MM_dd_HH.mm.ss");
+    QString fileName = tr("updatelog") + QString("_%1.txt").arg(timestamp);
+    QString filePath = QDir(desktopPath).absoluteFilePath(fileName);
+
+    QDBusPendingCall call = m_updateInter->ExportUpdateDetails(filePath);
+    QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [watcher] {
+        QDBusPendingReply<void> reply = *watcher;
+        if (reply.isError()) {
+            qCWarning(DCC_UPDATE_WORKER) << "Export update details failed, error: " << reply.error().message();
+            notifyInfo(tr("Update"), tr("Log export failed, please try again"));
+        } else {
+            notifyInfo(tr("Update"), tr("The log has been exported to the desktop"));
+        }
+        watcher->deleteLater();
+    });
+}
+
 void UpdateWorker::onLicenseStateChange()
 {
     QFutureWatcher<void>* watcher = new QFutureWatcher<void>(this);
@@ -1370,6 +1405,10 @@ void UpdateWorker::onCheckUpdateStatusChanged(const QString& value)
             if (!watcher->isError()) {
                 QDBusPendingReply<QString> reply = watcher->reply();
                 UpdateLogHelper::ref().handleUpdateLog(reply.value());
+                auto resultMap = m_model->getAllUpdateInfos();
+                for (UpdateType type : resultMap.keys()) {
+                    UpdateLogHelper::ref().updateItemInfo(resultMap.value(type));
+                }
             } else {
                 qCWarning(DCC_UPDATE_WORKER) << "Get update log failed";
             }
@@ -1403,6 +1442,10 @@ void UpdateWorker::onDownloadStatusChanged(const QString& value)
             return;
         }
         deleteJob(m_downloadJob);
+    } else if (value == "paused") {
+        m_model->setDownloadPaused(true);
+    } else if (value == "running") {
+        m_model->setDownloadPaused(false);
     }
 }
 
@@ -1415,7 +1458,7 @@ void UpdateWorker::onBackupStatusChanged(const QString &value)
         m_model->setLastError(BackupFailed, analyzeJobErrorMessage(description, BackupFailed));
         m_model->setBackupFailedTips(m_model->errorToText(m_model->lastError(BackupFailed)));
     } else if (value == "end") {
-        deleteJob(m_downloadJob);
+        deleteJob(m_backupJob);
     }
 }
 
