@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>Les actualitzacions del sistema estan desactivades. Poseu-vos en contacte amb l&apos;administrador per obtenir ajuda.</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>El sistema no està activat i no s&apos;ha pogut connectar per actualitzar-ne els serveis.</translation>
+        <source>View Update Log</source>
+        <translation>Mostra el registre d&apos;actualització</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Mostra&apos;n els detalls</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Actualitzacions:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Data de publicació:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Replega</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Versió:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Registre d&apos;actualització</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Tanca</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>Exporta a l&apos;escriptori</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -226,6 +237,37 @@
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation>Activeu els interruptors a Actualitza el contingut per obtenir-ne una experiència millor.</translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>El sistema no està activat i no s&apos;ha pogut connectar per actualitzar-ne els serveis.</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Les actualitzacions del sistema estan desactivades. Poseu-vos en contacte amb l&apos;administrador per obtenir ajuda.</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>El sistema té activada la funció de recuperació automàtica i no admet actualitzacions. Si teniu cap pregunta, poseu-vos en contacte amb l&apos;administrador de l&apos;empresa.</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>Les actualitzacions ja s&apos;han baixat. Què voleu fer?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Instal·lació silenciosa</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Actualitza i reinicia</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Actualitza i atura</translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -325,6 +367,14 @@
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
         <translation>Els usuaris del fòrum de nivell 2 o superior poden unir-se a la prova beta per rebre les últimes actualitzacions.</translation>
     </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Replega</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Només es permeten números entre 1 i 99999.</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Repositoris de tercers</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>registre d&apos;actualització</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>L&apos;exportació del registre ha fallat. Torneu-ho a provar.</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>El registre s&apos;ha exportat a l&apos;escriptori.</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Actualitza</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
