@@ -22,13 +22,9 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
+        <source>View Update Log</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -40,7 +36,7 @@
     </message>
     <message>
         <source>No update history</source>
-        <translation type="unfinished"/>
+        <translation>Keine Aktualisierungs-Chronik</translation>
     </message>
     <message>
         <source>System Updates</source>
@@ -52,7 +48,7 @@
     </message>
     <message>
         <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
-        <translation type="unfinished"/>
+        <translation>Liefert eine kumulative Aktualisierung mit neuen Möglichkeiten, Qualitäts- und Sicherheitsverbesserungen</translation>
     </message>
     <message>
         <source>Delivers security updates</source>
@@ -60,7 +56,7 @@
     </message>
     <message>
         <source>Installation date:</source>
-        <translation type="unfinished"/>
+        <translation>Installationsdatum:</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Details anzeigen</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Aktualisierungen:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Veröffentlichungsdatum:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Einfahren</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -216,14 +227,45 @@
     </message>
     <message>
         <source>Privacy Policy</source>
-        <translation type="unfinished"/>
+        <translation>Datenschutzerklärung</translation>
     </message>
     <message>
         <source>To use this software, you must accept the %1 that accompanies software updates.</source>
-        <translation type="unfinished"/>
+        <translation>Um diese Software zu benutzen, müssen die %1 akzeptieren, die den Software-Aktualisieren beigefügt ist.</translation>
     </message>
     <message>
         <source>Turn on the switches under Update Content to get better experiences</source>
+        <translation>Schalten Sie die Schalter bei Inhalt aktualisieren ein für bessere Ergebnisse</translation>
+    </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Ihr System ist nicht aktiviert, und konnte sich nicht mit den Aktualisierungsdiensten verbinden</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Die System-Aktualisierungen sind ausgeschaltet. Bitte kontaktieren Sie Ihren Administrator.</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -319,10 +361,18 @@
     </message>
     <message>
         <source>Expand</source>
-        <translation type="unfinished"/>
+        <translation>Aufklappen</translation>
     </message>
     <message>
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
+        <translation>Forumsteilnehmer auf Stufe 2 und höher können dem Betatest beitreten um die neuesten Aktualisierungen zu erhalten.</translation>
+    </message>
+    <message>
+        <source>Collapse</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Drittparteien-Repositorien</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>Protokoll erneuern</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Aktualisieren</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
@@ -448,15 +514,15 @@
     </message>
     <message>
         <source>Try Again</source>
-        <translation type="unfinished"/>
+        <translation>Nochmals probieren</translation>
     </message>
     <message>
         <source>Proceed to Update</source>
-        <translation type="unfinished"/>
+        <translation>Mit der Aktualisierung fortfahren</translation>
     </message>
     <message>
         <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
-        <translation type="unfinished"/>
+        <translation>Der Akku ist unter 60%. Um die Aktualisierung erfolgreich durchführen zu können schließen Sie bitte den Rechner ans Stromnetz an.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
