@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>Las actualizaciones del sistema están desactivadas. Póngase en contacto con su administrador para obtener ayuda.</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>Su sistema no está activado y no ha podido conectarse a los servicios de actualización</translation>
+        <source>View Update Log</source>
+        <translation>Ver registro de actualizaciones</translation>
     </message>
 </context>
 <context>
@@ -40,7 +36,7 @@
     </message>
     <message>
         <source>No update history</source>
-        <translation type="unfinished"/>
+        <translation>Sin historial de actualizaciones</translation>
     </message>
     <message>
         <source>System Updates</source>
@@ -52,7 +48,7 @@
     </message>
     <message>
         <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
-        <translation type="unfinished"/>
+        <translation>Ofrece una actualización acumulativa que incluye nuevas funciones, actualizaciones de calidad y seguridad</translation>
     </message>
     <message>
         <source>Delivers security updates</source>
@@ -60,7 +56,7 @@
     </message>
     <message>
         <source>Installation date:</source>
-        <translation type="unfinished"/>
+        <translation>Fecha de instalación:</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Ver detalles</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Actualizaciones:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Hora de lanzamiento:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Contraer</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Versión:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Registro de actualizaciones</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Cerrar</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>Exportar al escritorio</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -220,11 +231,42 @@
     </message>
     <message>
         <source>To use this software, you must accept the %1 that accompanies software updates.</source>
-        <translation>Para utilizar este software, debe aceptar el %1 que acompaña a las actualizaciones de software.</translation>
+        <translation>Para utilizar este software, debe aceptar la %1 que acompaña a las actualizaciones de software.</translation>
     </message>
     <message>
         <source>Turn on the switches under Update Content to get better experiences</source>
-        <translation type="unfinished"/>
+        <translation>Activa los interruptores en Actualizar contenido para obtener mejores experiencias</translation>
+    </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Su sistema no está activado y no ha podido conectarse a los servicios de actualización</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Las actualizaciones del sistema están desactivadas. Póngase en contacto con su administrador para obtener ayuda.</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>El sistema tiene activada la función de recuperación automática y no admite actualizaciones. Si tiene alguna pregunta, póngase en contacto con el administrador de la empresa.</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>Ya se han descargado las actualizaciones. ¿Qué quiere hacer?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Instalación silenciosa</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Actualizar y reiniciar</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Actualizar y apagar</translation>
     </message>
 </context>
 <context>
@@ -323,7 +365,15 @@
     </message>
     <message>
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation type="unfinished"/>
+        <translation>Los usuarios del foro de nivel 2 o superior pueden unirse a la prueba beta para recibir las últimas actualizaciones.</translation>
+    </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Contraer</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Sólo se admiten números entre 1-99999</translation>
     </message>
 </context>
 <context>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Repositorios de terceros</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>registro de actualizaciones</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>Error al exportar el registro, intentelo de nuevo</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>El registro se exportó al escritorio</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Actualizar</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
@@ -432,7 +498,7 @@
     </message>
     <message>
         <source>Backing up in progress</source>
-        <translation>Copia de seguridad en progreso</translation>
+        <translation>Copia de seguridad en progreso </translation>
     </message>
     <message>
         <source>Backup failed</source>
@@ -456,7 +522,7 @@
     </message>
     <message>
         <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
-        <translation type="unfinished"/>
+        <translation>La capacidad de la batería es inferior al 60%. Para obtener actualizaciones exitosas, conéctese.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
