@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>Päivitykset ovat poistettu käytöstä. Pyydä apua järjestelmänvalvojaltasi.</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>Tietokonetta ei ole aktivoitu, eikä se onnistu saamaan yhteyttä päivityspalveluihin.</translation>
+        <source>View Update Log</source>
+        <translation>Näytä päivitysloki</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Näytä tiedot</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Päivitykset:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Julkaisupäivä:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Tiivistetty</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Versio:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Päivitysloki</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Sulje</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>Vie työpöydälle</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -226,6 +237,37 @@
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation>Ota käyttöön &quot;Päivitä sisältö&quot; kytkimet saadaksesi paremman kokemuksen</translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Tietokonetta ei ole aktivoitu, eikä se onnistu saamaan yhteyttä päivityspalveluihin.</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Päivitykset ovat poistettu käytöstä. Pyydä apua järjestelmänvalvojaltasi.</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>Tietokoneeseen on määritetty automaattinen palautustoiminto, eikä se tue päivitysten asennusta. Jos sinulla on kysyttävää, ota yhteyttä yrityksen järjestelmänvalvojaan.</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>Päivitykset on jo ladattu. Mitä haluat tehdä?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Hiljainen asennus</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Päivitä ja käynnistä</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Päivitä ja sammuta</translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -323,7 +365,15 @@
     </message>
     <message>
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation type="unfinished"/>
+        <translation>Foorumin käyttäjät tasolla 2 ja sitä korkeammalla voivat liittyä beta-testiin viimeisillä päivityksillä.</translation>
+    </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Tiivistetty</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Numerot väliltä 1-99999 ovat sallittuja</translation>
     </message>
 </context>
 <context>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Kolmannen osapuolen pakettivarastot</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>päivitysloki</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>Lokin vienti epäonnistui, yritä uudelleen</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>Loki on viety työpöydälle</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Päivitä</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
