@@ -24,13 +24,9 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
+        <source>View Update Log</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -71,10 +67,6 @@
         <source>View Details</source>
         <translation>Мүмкіндіктерін көр</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Жаңылар:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Жарыс жылы:</translation>
@@ -83,6 +75,25 @@
         <source>Collapse</source>
         <translation>Жыртық</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -228,6 +239,37 @@
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -327,6 +369,14 @@
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Collapse</source>
+        <translation type="unfinished">Жыртық</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
@@ -346,6 +396,22 @@
         <source>Third-party Repositories</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>update</name>
