@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>Systeemupdates zijn uitgeschakeld. Neem contact op met je systeembeheerder.</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>Er kan geen verbinding worden gemaakt, omdat je systeem niet is geactiveerd.</translation>
+        <source>View Update Log</source>
+        <translation>Updatelogboek bekijken</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Details bekijken</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Updates:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Uitgebracht op:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Inklappen</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Versie:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Updatelogboek</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Sluiten</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>Exporteren naar bureaublad</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -226,6 +237,37 @@
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation>Schakel de opties onder ‘Update-inhoud’ in om de gebruikservaring te verbeteren</translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Er kan geen verbinding worden gemaakt, omdat je systeem niet is geactiveerd.</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Systeemupdates zijn uitgeschakeld. Neem contact op met je systeembeheerder.</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>Automatisch herstel is ingeschakeld - updates zijn hierdoor niet mogelijk. Neem contact op met de systeembeheerder.</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>De updates zijn gedownload. Welke actie wil je uitvoeren?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Stille installatie</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Bijwerken en herstarten</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Bijwerken en afsluiten</translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -323,7 +365,15 @@
     </message>
     <message>
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation type="unfinished"/>
+        <translation>Forumgebruikers met niveau 2 of hoger kunnen deelnemen aan de bètatest.</translation>
+    </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Inklappen</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Alleen getallen tussen de 1 en 99999 zijn toegestaan</translation>
     </message>
 </context>
 <context>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Externe pakketbronnen</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>updatelogboek</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>Exporteren mislukt - probeer het opnieuw</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>Het logboek is opgeslagen op het bureaublad</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Bijwerken</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
