@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>Aktualizacje systemowe są wyłączone. Skontaktuj się z administratorem, aby uzyskać pomoc</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>Twój system nie jest aktywowany i nie udało mu się połączyć z usługą aktualizacji</translation>
+        <source>View Update Log</source>
+        <translation>Pokaż dziennik aktualizacji</translation>
     </message>
 </context>
 <context>
@@ -60,7 +56,7 @@
     </message>
     <message>
         <source>Installation date:</source>
-        <translation>Data instalacji:</translation>
+        <translation>Data instalacji: </translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Wyświetl szczegóły</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Aktualizacje:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Data wydania:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Zwiń</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Wersja:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Dziennik aktualizacji</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Zamknij</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>Wyślij na pulpit</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -184,11 +195,11 @@
     </message>
     <message>
         <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
-        <translation>Nie udało się utworzyć kopii zapasowej. Jeśli kontynuujesz aktualizacje, nie będziesz mógł przywrócić starego systemu.</translation>
+        <translation>Nie udało się utworzyć kopii zapasowej. Kontynuując, nie będzie można przywrócić starego systemu.</translation>
     </message>
     <message>
         <source>If you continue the updates, you cannot roll back to the old system later.</source>
-        <translation>Jeśli kontynuujesz aktualizacje, nie będziesz mógł przywrócić starego systemu.</translation>
+        <translation>Kontynuując, nie będzie można przywrócić starego systemu.</translation>
     </message>
     <message>
         <source>Insufficient disk space</source>
@@ -216,16 +227,47 @@
     </message>
     <message>
         <source>Privacy Policy</source>
-        <translation>Polityka prywatności</translation>
+        <translation>Politykę prywatności</translation>
     </message>
     <message>
         <source>To use this software, you must accept the %1 that accompanies software updates.</source>
-        <translation>Aby korzystać z tego oprogramowania, musisz zaakceptować %1, dołączone do aktualizacji.</translation>
+        <translation>Aby korzystać z tego oprogramowania, musisz zaakceptować %1, dołączoną do aktualizacji.</translation>
     </message>
     <message>
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation>Sprawdź ustawienia, aby usprawnić proces aktualizacji</translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Twój system nie jest aktywowany i nie udało mu się połączyć z usługą aktualizacji</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Aktualizacje systemu są wyłączone. Skontaktuj się z administratorem, aby uzyskać pomoc</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>System posiada włączoną funkcję automatycznego przywracania i nie wspiera aktualizacji. Jeśli posiadasz jakiekolwiek pytania, skontaktuj się z administratorem.</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>Aktualizacje zostały pobrane. Co chcesz zrobić?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Cicha instalacja</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Zaktualizuj i uruchom ponownie</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Zaktualizuj i zamknij</translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -275,7 +317,7 @@
     </message>
     <message>
         <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
-        <translation>Włączenie &quot;Automatyczne pobieranie aktualizacji&quot; zainstaluje automatycznie aktualizacje po wykryciu połączenia z Internetem</translation>
+        <translation>Włączenie &quot;Automatyczne pobieranie aktualizacji&quot; automatycznie zainstaluje aktualizacje po wykryciu połączenia z Internetem</translation>
     </message>
     <message>
         <source>Download when Inactive</source>
@@ -323,7 +365,15 @@
     </message>
     <message>
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation type="unfinished"/>
+        <translation>Użytkownicy forum na poziomie 2 lub wyższym mogą dołączyć do testów Beta i uzyskać najnowsze aktualizacje.</translation>
+    </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Zwiń</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Dozwolone są tylko liczby w zakresie 1-99999</translation>
     </message>
 </context>
 <context>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Zewnętrzne repozytoria</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>Dziennik aktualizacji</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>Błąd eksportowania dzienników, spróbuj ponownie</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>Wysłano dzienniki na pulpit</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Aktualizuj</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
@@ -444,7 +510,7 @@
     </message>
     <message>
         <source>If you continue the updates, you cannot roll back to the old system later.</source>
-        <translation>Jeśli kontynuujesz aktualizacje, nie będziesz mógł przywrócić starego systemu.</translation>
+        <translation>Kontynuując, nie będzie można przywrócić starego systemu.</translation>
     </message>
     <message>
         <source>Try Again</source>
