@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>As atualizações do sistema estão desativadas. Por favor, entre em contato com o administrador para obter ajuda.</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>Seu sistema não está ativado e não conseguiu conectar aos serviços de atualização.</translation>
+        <source>View Update Log</source>
+        <translation>Exibir log de atualizações</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Ver detalhes</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Atualizações:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Data de lançamento:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Recolher</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Versão:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Log de atualizações</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Fechar</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>Exportar para a área de trabalho</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -226,6 +237,37 @@
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation>Ative os interruptores em Conteúdo da Atualização para obter uma melhor experiência</translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Seu sistema não está ativado e por isso não conseguiu se conectar aos serviços de atualização</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>As atualizações do sistema estão desabilitadas. Entre em contato com o administrador para obter ajuda.</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>O sistema ativou a função de recuperação automática e não permite atualizações. Se tiver dúvidas, entre em contato com o administrador</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>As atualizações já foram baixadas. O que você quer fazer?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Instalação silenciosa</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Atualizar e reiniciar</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Atualizar e desligar</translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -315,7 +357,7 @@
     </message>
     <message>
         <source>Click here to complete the application</source>
-        <translation>Clique aqui para completar a aplicação</translation>
+        <translation>Clique aqui para concluir a participação</translation>
     </message>
     <message>
         <source>Expand</source>
@@ -323,7 +365,15 @@
     </message>
     <message>
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation type="unfinished"/>
+        <translation>Os usuários com nível 2 ou superior no fórum podem participar do programa beta para testar as últimas atualizações.</translation>
+    </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Recolher</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Somente números entre 1-99999 são permitidos</translation>
     </message>
 </context>
 <context>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Repositórios de terceiros</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>updatelog</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>A exportação do log falhou, tente novamente</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>O log foi exportado para a área de trabalho</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Atualizar</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
