@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>Përditësimet e sistemit janë të çaktivizuara. Ju lutemi, për ndihmë, lidhuni me përgjegjësin tuaj</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>Sistemi juaj s’është aktivizuar dhe s’u arrit të lidhej me shërbime përditësimesh</translation>
+        <source>View Update Log</source>
+        <translation>Shihni Regjistra Përditësimesh</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Shihni Hollësitë</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Përditësime:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Kohë hedhjeje në qarkullim:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Palose</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Version:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Regjistër Përditësimesh</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Mbylle</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>Eksportoje në desktop</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -226,6 +237,37 @@
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation>Për të pasur punim më të mirë, hapni çelësat që gjenden nën Lëndë Përditësimi</translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Sistemi juaj s’është aktivizuar dhe s’u arrit të lidhej me shërbime përditësimesh</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Përditësimet e sistemit janë të çaktivizuara. Ju lutemi, për ndihmë, lidhuni me përgjegjësin tuaj</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>Sistemi ka të aktivizuar funksion rikthimi dhe s’mbulon përditësime. Nëse keni ndonjë pyetje, ju lutemi, lidhuni me përgjegjësin.</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>Përditësimet janë shkarkuar tashmë. Ç’doni të bëhet?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Instalim Heshtazi</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Përditësoje dhe Rinisu</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Përditësoje dhe Fiku</translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -325,6 +367,14 @@
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
         <translation>Përdorues forumi të nivelit 2 e më sipër mund të bëhen pjesë e testimeve beta, që të marrin përditësimet më të reja.</translation>
     </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Palose</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Lejohen vetëm numra mes 1-99999</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Depo Palësh të Treta</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>Eksportimi i regjistrit dështoi, ju lutemi, riprovoni</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>Regjistri u eksportua te desktopi</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Përditësim</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
