@@ -1,68 +1,62 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="tr">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
 <context>
     <name>CheckUpdate</name>
     <message>
         <source>Last check: </source>
-        <translation type="unfinished"></translation>
+        <translation>Son kontrol:</translation>
     </message>
 </context>
 <context>
     <name>QuitTestingChannelDialog</name>
     <message>
         <source>If you exit the beta program, you will no longer receive beta updates.</source>
-        <translation type="unfinished"></translation>
+        <translation>Beta programından çıkarsanız artık beta güncellemeleri almayacaksınız.</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>İptal et</translation>
     </message>
     <message>
         <source>Exit</source>
-        <translation type="unfinished"></translation>
+        <translation>Çık</translation>
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation type="unfinished"></translation>
+        <source>View Update Log</source>
+        <translation>Güncelleme Günlüğünü Görüntüle</translation>
     </message>
 </context>
 <context>
     <name>UpdateHistoryDialog</name>
     <message>
         <source>Update History</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme Geçmişi</translation>
     </message>
     <message>
         <source>No update history</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme geçmişi yok</translation>
     </message>
     <message>
         <source>System Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem Güncellemeleri</translation>
     </message>
     <message>
         <source>Security Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Güvenlik Güncellemeleri</translation>
     </message>
     <message>
         <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Yeni özellikler, kalite güncellemeleri ve güvenlik güncellemeleri de dahil olmak üzere toplu bir güncelleme sunar</translation>
     </message>
     <message>
         <source>Delivers security updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Güvenlik güncellemeleri sunar</translation>
     </message>
     <message>
         <source>Installation date:</source>
-        <translation type="unfinished"></translation>
+        <translation>Kurulum tarihi:</translation>
     </message>
 </context>
 <context>
@@ -71,10 +65,6 @@
         <source>View Details</source>
         <translation>Ayrıntıları Görüntüle</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Güncellemeler:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Yayın zamanı:</translation>
@@ -83,74 +73,93 @@
         <source>Collapse</source>
         <translation>Daralt</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Sürüm:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Güncelleme Günlüğü</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Kapat</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
     <message>
         <source>NONE</source>
-        <translation type="unfinished"></translation>
+        <translation>HİÇBİRİ</translation>
     </message>
     <message>
         <source>LOW</source>
-        <translation type="unfinished"></translation>
+        <translation>DÜŞÜK</translation>
     </message>
     <message>
         <source>MEDIUM</source>
-        <translation type="unfinished"></translation>
+        <translation>ORTA</translation>
     </message>
     <message>
         <source>HIGH</source>
-        <translation type="unfinished"></translation>
+        <translation>YÜKSEK</translation>
     </message>
     <message>
         <source>CRITICAL</source>
-        <translation type="unfinished"></translation>
+        <translation>KRİTİK</translation>
     </message>
     <message>
         <source>critical-risk</source>
-        <translation type="unfinished"></translation>
+        <translation>kritik risk</translation>
     </message>
     <message>
         <source>high-risk</source>
-        <translation type="unfinished"></translation>
+        <translation>yüksek riskli</translation>
     </message>
     <message>
         <source>medium-risk</source>
-        <translation type="unfinished"></translation>
+        <translation>orta riskli</translation>
     </message>
     <message>
         <source>low-risk</source>
-        <translation type="unfinished"></translation>
+        <translation>düşük riskli</translation>
     </message>
     <message>
         <source>unknown</source>
-        <translation type="unfinished"></translation>
+        <translation>bilinmeyen</translation>
     </message>
     <message>
         <source>This update fixes</source>
-        <translation type="unfinished"></translation>
+        <translation>Bu güncelleme şunları düzeltir</translation>
     </message>
     <message>
         <source>vulnerabilities</source>
-        <translation type="unfinished"></translation>
+        <translation>güvenlik açıkları</translation>
     </message>
     <message>
         <source>vulnerability</source>
-        <translation type="unfinished"></translation>
+        <translation>güvenlik açığı</translation>
     </message>
     <message>
         <source>%1 of %2 %3</source>
-        <translation type="unfinished"></translation>
+        <translation>%2 %3 de %1</translation>
         <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
     </message>
     <message>
         <source>, </source>
-        <translation type="unfinished"></translation>
+        <translation>, </translation>
         <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
     </message>
     <message>
         <source>for more details, please visit </source>
-        <translation type="unfinished"></translation>
+        <translation>daha fazla bilgi için, lütfen ziyaret edin</translation>
         <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
     </message>
 </context>
@@ -166,67 +175,98 @@
     </message>
     <message>
         <source>Unknown error</source>
-        <translation type="unfinished">Bilinmeyen hata</translation>
+        <translation>Bilinmeyen hata</translation>
     </message>
     <message>
         <source>Downloading updates failed. Please free up %1 disk space first.</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncellemeleri indirme başarısız oldu. Lütfen önce %1 disk alanını boşaltın.</translation>
     </message>
     <message>
         <source>Dependency error, failed to detect the updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Bağımlılık hatası, güncellemeleri algılama başarısız oldu</translation>
     </message>
     <message>
         <source>Please check your network and try again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Lütfen ağınızı kontrol edip tekrar deneyin.</translation>
     </message>
     <message>
         <source>Downloading updates failed. Please check your network and try again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncellemeler indirilemedi. Lütfen ağınızı kontrol edin ve tekrar deneyin.</translation>
     </message>
     <message>
         <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem yedeklemesi gerçekleştirilemiyor. Güncellemelere devam ederseniz, daha sonra eski sisteme geri dönemezsiniz.</translation>
     </message>
     <message>
         <source>If you continue the updates, you cannot roll back to the old system later.</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncellemeleri devam ettirirseniz daha sonra eski sisteme geri dönüş yapamazsınız.</translation>
     </message>
     <message>
         <source>Insufficient disk space</source>
-        <translation type="unfinished"></translation>
+        <translation>Yetersiz disk alanı</translation>
     </message>
     <message>
         <source>DPKG error</source>
-        <translation type="unfinished"></translation>
+        <translation>DPKG hatası</translation>
     </message>
     <message>
         <source>File missing</source>
-        <translation type="unfinished"></translation>
+        <translation>Dosya eksik</translation>
     </message>
     <message>
         <source>Service connection is abnormal, please check the network and try again</source>
-        <translation type="unfinished"></translation>
+        <translation>Servis bağlantısı anormal, lütfen ağı kontrol edin ve tekrar deneyin</translation>
     </message>
     <message>
         <source>The repository source configuration is not valid, please check and try again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Depo kaynak yapılandırması geçerli değil, lütfen kontrol edip tekrar deneyin.</translation>
     </message>
     <message>
         <source>Check Again</source>
-        <translation type="unfinished">Tekrar Kontrol Et</translation>
+        <translation>Tekrar Kontrol Edin</translation>
     </message>
     <message>
         <source>Privacy Policy</source>
-        <translation type="unfinished"></translation>
+        <translation>Gizlilik Politikası</translation>
     </message>
     <message>
         <source>To use this software, you must accept the %1 that accompanies software updates.</source>
-        <translation type="unfinished"></translation>
+        <translation>Bu yazılımı kullanabilmeniz için yazılım güncellemelerine eşlik eden %1&apos;i kabul etmeniz gerekmektedir.</translation>
     </message>
     <message>
         <source>Turn on the switches under Update Content to get better experiences</source>
-        <translation type="unfinished"></translation>
+        <translation>Daha iyi deneyimler elde etmek için İçeriği Güncelle altındaki anahtarları açın</translation>
+    </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Sisteminiz etkinleştirilmedi ve güncelleme hizmetlerine bağlanamadı</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Sistem güncellemeleri devre dışı bırakıldı. Lütfen yardım için yöneticinizle iletişime geçin</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>Güncellemeler zaten indirildi. Ne yapmak istiyorsunuz?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Sessiz Kurulum</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Güncelle ve Yeniden Başlat</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Güncelle ve Kapat</translation>
     </message>
 </context>
 <context>
@@ -237,125 +277,149 @@
     </message>
     <message>
         <source>Update Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme Türü</translation>
     </message>
     <message>
         <source>Function Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Fonksiyon Güncellemeleri</translation>
     </message>
     <message>
         <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Yeni özellikler, kalite güncellemeleri ve güvenlik güncellemeleri de dahil olmak üzere toplu bir güncelleme sunar</translation>
     </message>
     <message>
         <source>Security Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Güvenlik Güncellemeleri</translation>
     </message>
     <message>
         <source>Delivers security updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Güvenlik güncellemeleri sunar</translation>
     </message>
     <message>
         <source>Third-party Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Üçüncü Taraf Güncellemeleri</translation>
     </message>
     <message>
         <source>Delivers  updates for additional repository sources</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Advanced Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Ek depolama kaynakları için güncellemeler sunar</translation>
     </message>
     <message>
         <source>Limit Speed</source>
-        <translation type="unfinished"></translation>
+        <translation>Hızı Sınırla</translation>
     </message>
     <message>
         <source>Limit Setting</source>
-        <translation type="unfinished"></translation>
+        <translation>Sınır Ayarı</translation>
     </message>
     <message>
         <source>Auto Download</source>
-        <translation type="unfinished"></translation>
+        <translation>Otomatik İndirme</translation>
     </message>
     <message>
         <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;Güncellemeleri Otomatik İndir&quot; seçeneğinin etkinleştirilmesi, internete bağlanıldığında güncellemelerin otomatik olarak indirilmesini sağlar</translation>
     </message>
     <message>
         <source>Download when Inactive</source>
-        <translation type="unfinished"></translation>
+        <translation>Etkin Değilken İndir</translation>
     </message>
     <message>
         <source>Start at</source>
-        <translation type="unfinished"></translation>
+        <translation>Başlama</translation>
     </message>
     <message>
         <source>End at</source>
-        <translation type="unfinished"></translation>
+        <translation>Bitiş</translation>
+    </message>
+    <message>
+        <source>Advanced Settings</source>
+        <translation>Gelişmiş Ayarlar</translation>
     </message>
     <message>
         <source>Updates Notification</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme Bildirimi</translation>
     </message>
     <message>
         <source>Clear Package Cache</source>
-        <translation type="unfinished"></translation>
+        <translation>Paket Önbelleğini Temizle</translation>
     </message>
     <message>
         <source>Update History</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme Geçmişi</translation>
     </message>
     <message>
         <source>View</source>
-        <translation type="unfinished">Görünüm</translation>
+        <translation>Görüntüle</translation>
     </message>
     <message>
         <source>Join Internal Testing Channel</source>
-        <translation type="unfinished"></translation>
+        <translation>Dahili Test Kanalına Katılın</translation>
     </message>
     <message>
         <source>Click here to complete the application</source>
-        <translation type="unfinished"></translation>
+        <translation>Başvuruyu tamamlamak için buraya tıklayın</translation>
     </message>
     <message>
         <source>Expand</source>
-        <translation type="unfinished"></translation>
+        <translation>Genişlet</translation>
     </message>
     <message>
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation type="unfinished"></translation>
+        <translation>Seviye 2 ve üzeri forum kullanıcıları son güncellemeleri almak için beta testine katılabilir.</translation>
+    </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Daralt</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Sadece 1-99999 arasındaki sayılara izin verilir</translation>
     </message>
 </context>
 <context>
     <name>UpdateWorker</name>
     <message>
         <source>System Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem Güncellemeleri</translation>
     </message>
     <message>
         <source>Fixed some known bugs and security vulnerabilities</source>
-        <translation type="unfinished"></translation>
+        <translation>Bilinen bazı hatalar ve güvenlik açıkları düzeltildi</translation>
     </message>
     <message>
         <source>Security Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Güvenlik Güncellemeleri</translation>
     </message>
     <message>
         <source>Third-party Repositories</source>
-        <translation type="unfinished"></translation>
+        <translation>Üçüncü Taraf Depolar</translation>
+    </message>
+    <message>
+        <source>updatelog</source>
+        <translation>güncelleme günlüğü</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>Günlük aktarımı başarısız oldu, lütfen tekrar deneyin</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>Günlük masaüstüne aktarıldı</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Güncelle</translation>
     </message>
 </context>
 <context>
     <name>update</name>
     <message>
         <source>System Update</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem Güncellemesi</translation>
     </message>
     <message>
         <source>System update and upgrade</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistem güncelleme ve yükseltme</translation>
     </message>
 </context>
 <context>
@@ -364,101 +428,101 @@
         <source>Update Settings</source>
         <translation>Güncelleme Ayarları</translation>
     </message>
-    <message>
-        <source>Update installation successful</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Reboot now</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Installation update failed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Continue Update</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Installing updates...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Installing</source>
-        <translation type="unfinished">Kuruluyor</translation>
+        <translation>Kuruluyor</translation>
     </message>
     <message>
         <source>Update download completed</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme indirme işlemi tamamlandı</translation>
     </message>
     <message>
         <source>Install updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncellemeleri yükle</translation>
     </message>
     <message>
         <source>Update size: </source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme boyutu: </translation>
     </message>
     <message>
         <source>Update download failed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Retry</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme indirmesi başarısız oldu</translation>
     </message>
     <message>
         <source>Downloading updates...</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncellemeler indiriliyor...</translation>
     </message>
     <message>
         <source>Downloading</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Updates Available</source>
-        <translation type="unfinished">Güncelleme Kullanılabilir</translation>
-    </message>
-    <message>
-        <source>Download</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Backing up in progress...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Backing up in progress</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Backup failed</source>
-        <translation type="unfinished"></translation>
+        <translation>İndiriliyor</translation>
     </message>
     <message>
         <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncelleme ayarlarını, Güvenlik Güncellemelerini, Otomatik İndirme Güncellemelerini ve Güncelleme Bildirimlerini yapılandırın</translation>
+    </message>
+    <message>
+        <source>Reboot now</source>
+        <translation>Şimdi yeniden başlat</translation>
+    </message>
+    <message>
+        <source>Download</source>
+        <translation>İndir</translation>
+    </message>
+    <message>
+        <source>Installing updates...</source>
+        <translation>Güncellemeler yükleniyor...</translation>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation>Tekrar dene</translation>
+    </message>
+    <message>
+        <source>Continue Update</source>
+        <translation>Güncellemeye Devam Et</translation>
+    </message>
+    <message>
+        <source>Updates Available</source>
+        <translation>Güncellemeler Mevcut</translation>
+    </message>
+    <message>
+        <source>Installation update failed</source>
+        <translation>Kurulum güncellemesi başarısız oldu</translation>
+    </message>
+    <message>
+        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
+        <translation>Sisteminizin ve uygulamalarınızın düzgün çalışmasını sağlamak için lütfen güncellemeden sonra bilgisayarınızı yeniden başlatın</translation>
+    </message>
+    <message>
+        <source>Backing up in progress...</source>
+        <translation>Yedekleme işlemi devam ediyor...</translation>
+    </message>
+    <message>
+        <source>Backing up in progress</source>
+        <translation>Yedekleme devam ediyor</translation>
+    </message>
+    <message>
+        <source>Backup failed</source>
+        <translation>Yedekleme başarısız oldu</translation>
+    </message>
+    <message>
+        <source>Update installation successful</source>
+        <translation>Güncelleme kurulumu başarılı</translation>
     </message>
     <message>
         <source>If you continue the updates, you cannot roll back to the old system later.</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncellemeleri devam ettirirseniz daha sonra eski sisteme geri dönüş yapamazsınız.</translation>
     </message>
     <message>
         <source>Try Again</source>
-        <translation type="unfinished"></translation>
+        <translation>Tekrar deneyin</translation>
     </message>
     <message>
         <source>Proceed to Update</source>
-        <translation type="unfinished"></translation>
+        <translation>Güncellemeye Devam Et</translation>
     </message>
     <message>
         <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
-        <translation type="unfinished"></translation>
+        <translation>Pil kapasitesi %60&apos;tan düşük. Başarılı güncellemeler almak için lütfen güç kablosunu takın.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
