@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation type="unfinished"/>
+        <source>View Update Log</source>
+        <translation>Переглянути журнал оновлення</translation>
     </message>
 </context>
 <context>
@@ -40,7 +36,7 @@
     </message>
     <message>
         <source>No update history</source>
-        <translation type="unfinished"/>
+        <translation>Немає журналу оновлень</translation>
     </message>
     <message>
         <source>System Updates</source>
@@ -48,11 +44,11 @@
     </message>
     <message>
         <source>Security Updates</source>
-        <translation type="unfinished"/>
+        <translation>Оновлення захисту</translation>
     </message>
     <message>
         <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
-        <translation type="unfinished"/>
+        <translation>Накопичувальне оновлення драйверів із включенням нових можливостей, оновленнями якості та оновленнями захисту</translation>
     </message>
     <message>
         <source>Delivers security updates</source>
@@ -60,7 +56,7 @@
     </message>
     <message>
         <source>Installation date:</source>
-        <translation type="unfinished"/>
+        <translation>Дата встановлення:</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>Переглянути подробиці</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>Оновлення:</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>Час випуску:</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>Згорнути</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Версія:</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>Журнал оновлення</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Закрити</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>Експортувати до стільниці</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -224,7 +235,38 @@
     </message>
     <message>
         <source>Turn on the switches under Update Content to get better experiences</source>
-        <translation type="unfinished"/>
+        <translation>Увімкніть пункти у розділі «Оновлення даних», щоб оптимізувати роботу</translation>
+    </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>Вашу систему не активовано, і вона не змогла встановити з&apos;єднання зі службами оновлення</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>Оновлення системи вимкнено. Будь ласка, зв&apos;яжіться із адміністратором для довідки.</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>У системі увімкнено функціональну можливість автоматичного відновлення і не передбачено підтримки оновлень. Якщо у вас є якісь питання, будь ласка, зв&apos;яжіться із промисловим адміністратором.</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>Оновлення вже отримано. Що робити?</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>Автономне встановлення</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Оновити і перезавантажити</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Оновити і вимкнути</translation>
     </message>
 </context>
 <context>
@@ -323,7 +365,15 @@
     </message>
     <message>
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation type="unfinished"/>
+        <translation>Користувачі форуму рівня 2 та вищих рівнів можуть долучатися до тестування для отримання найсвіжіших оновлень.</translation>
+    </message>
+    <message>
+        <source>Collapse</source>
+        <translation>Згорнути</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>Можна використовувати лише числа у діапазоні 1-99999</translation>
     </message>
 </context>
 <context>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>Сторонні сховища</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>журнал_оновлення</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>Не вдалося експортувати журнал. Будь ласка, повторіть спробу</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>Журнал було експортовано до стільниці</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Оновлення</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
@@ -456,7 +522,7 @@
     </message>
     <message>
         <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
-        <translation type="unfinished"/>
+        <translation>Батарею заряджено менше ніж на 60%. Для успішного оновлення, будь ласка, з&apos;єднайте пристрій із джерелом струму.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
