@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>系统已被禁止更新，请联系管理员！</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>当前系统未激活，无法启动更新服务</translation>
+        <source>View Update Log</source>
+        <translation>查看更新日志</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>查看详细信息</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>更新：</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>发布时间：</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>收起</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>版本：</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>更新日志</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>关闭</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>导出至桌面</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -226,6 +237,37 @@
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation>开启更新内容开关，可以获得更优质的功能体验哦</translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>当前系统未激活，无法启动更新服务</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>系统已被禁止更新，请联系管理员！</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>系统已开启无忧还原功能，不支持更新，如有疑问请联系企业管理员</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>更新包已下载完毕，请选择您要执行的操作</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>后台静默安装</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>更新并重启</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>更新并关机</translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -243,7 +285,7 @@
     </message>
     <message>
         <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
-        <translation>提供新功能、质量补丁、安全漏洞修复登全量更新内容</translation>
+        <translation>提供新功能、质量补丁、安全漏洞修复等全量更新内容</translation>
     </message>
     <message>
         <source>Security Updates</source>
@@ -325,6 +367,14 @@
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
         <translation>论坛2级及以上用户可加入内测，获取最新更新</translation>
     </message>
+    <message>
+        <source>Collapse</source>
+        <translation>收起</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>只允许输入1-99999</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>第三方仓库</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>更新日志</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>日志导出失败，请重试尝试</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>日志已导出至桌面</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>更新</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
@@ -392,7 +458,7 @@
     </message>
     <message>
         <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
-        <translation>可设置系統更新、安全更折、闲时更新、更新提醒等</translation>
+        <translation>可设置系統更新、安全更新、闲时更新、更新提醒等</translation>
     </message>
     <message>
         <source>Reboot now</source>
