@@ -22,14 +22,10 @@
     </message>
 </context>
 <context>
-    <name>UpdateDisable</name>
+    <name>UpdateControl</name>
     <message>
-        <source>The system updates are disabled. Please contact your administrator for help</source>
-        <translation>系統已被禁止更新，請聯繫管理員！</translation>
-    </message>
-    <message>
-        <source>Your system is not activated, and it failed to connect to update services</source>
-        <translation>當前系統未激活，無法啓動更新服務</translation>
+        <source>View Update Log</source>
+        <translation>查看更新日誌</translation>
     </message>
 </context>
 <context>
@@ -69,10 +65,6 @@
         <source>View Details</source>
         <translation>查看詳細信息</translation>
     </message>
-    <message>
-        <source>Updates:</source>
-        <translation>更新：</translation>
-    </message>
     <message>
         <source>Release time:</source>
         <translation>發佈時間：</translation>
@@ -81,6 +73,25 @@
         <source>Collapse</source>
         <translation>收起</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>版本：</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateLogDialog</name>
+    <message>
+        <source>Update Log</source>
+        <translation>更新日誌</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>關閉</translation>
+    </message>
+    <message>
+        <source>Export to desktop</source>
+        <translation>導出至桌面</translation>
+    </message>
 </context>
 <context>
     <name>UpdateLogHelper</name>
@@ -226,6 +237,37 @@
         <source>Turn on the switches under Update Content to get better experiences</source>
         <translation>開啓更新內容開關，可以獲得更優質的功能體驗哦</translation>
     </message>
+    <message>
+        <source>Your system is not activated, and it failed to connect to update services</source>
+        <translation>當前系統未激活，無法啓動更新服務</translation>
+    </message>
+    <message>
+        <source>The system updates are disabled. Please contact your administrator for help</source>
+        <translation>系統已被禁止更新，請聯繫管理員！</translation>
+    </message>
+    <message>
+        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
+        <translation>系統已開啓無憂還原功能，不支持更新，如有疑問請聯繫企業管理員</translation>
+    </message>
+</context>
+<context>
+    <name>UpdateSelectDialog</name>
+    <message>
+        <source>The updates have been already downloaded. What do you want to do?</source>
+        <translation>更新包已下載完畢，請選擇您要執行的操作</translation>
+    </message>
+    <message>
+        <source>Silent Installation</source>
+        <translation>後台靜默安裝</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>更新並重啓</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>更新並關機</translation>
+    </message>
 </context>
 <context>
     <name>UpdateSetting</name>
@@ -325,6 +367,14 @@
         <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
         <translation>論壇2級及以上用户可加入內測，獲取最新更新</translation>
     </message>
+    <message>
+        <source>Collapse</source>
+        <translation>收起</translation>
+    </message>
+    <message>
+        <source>Only numbers between 1-99999 are allowed</source>
+        <translation>只允許輸入1-99999</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
@@ -344,6 +394,22 @@
         <source>Third-party Repositories</source>
         <translation>第三方倉庫</translation>
     </message>
+    <message>
+        <source>updatelog</source>
+        <translation>更新日誌</translation>
+    </message>
+    <message>
+        <source>Log export failed, please try again</source>
+        <translation>日誌導出失敗，請重試嘗試</translation>
+    </message>
+    <message>
+        <source>The log has been exported to the desktop</source>
+        <translation>日誌已導出至桌面</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>更新</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
